/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BeyondcorpSecurityGatewayConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. An arbitrary user-provided name for the SecurityGateway.
    * Cannot exceed 64 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#display_name BeyondcorpSecurityGateway#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#id BeyondcorpSecurityGateway#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource within its parent collection as described in https://google.aip.dev/122. Must be omitted or set to 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#location BeyondcorpSecurityGateway#location}
    */
    readonly location?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#project BeyondcorpSecurityGateway#project}
    */
    readonly project?: string;
    /**
    * Optional. User-settable SecurityGateway resource ID.
    * * Must start with a letter.
    * * Must contain between 4-63 characters from '/a-z-/'.
    * * Must end with a number or letter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#security_gateway_id BeyondcorpSecurityGateway#security_gateway_id}
    */
    readonly securityGatewayId: string;
    /**
    * hubs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#hubs BeyondcorpSecurityGateway#hubs}
    */
    readonly hubs?: BeyondcorpSecurityGatewayHubs[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#timeouts BeyondcorpSecurityGateway#timeouts}
    */
    readonly timeouts?: BeyondcorpSecurityGatewayTimeouts;
}
export interface BeyondcorpSecurityGatewayHubsInternetGateway {
}
export declare function beyondcorpSecurityGatewayHubsInternetGatewayToTerraform(struct?: BeyondcorpSecurityGatewayHubsInternetGatewayOutputReference | BeyondcorpSecurityGatewayHubsInternetGateway): any;
export declare function beyondcorpSecurityGatewayHubsInternetGatewayToHclTerraform(struct?: BeyondcorpSecurityGatewayHubsInternetGatewayOutputReference | BeyondcorpSecurityGatewayHubsInternetGateway): any;
export declare class BeyondcorpSecurityGatewayHubsInternetGatewayOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): BeyondcorpSecurityGatewayHubsInternetGateway | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayHubsInternetGateway | undefined);
    get assignedIps(): string[];
}
export interface BeyondcorpSecurityGatewayHubs {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#region BeyondcorpSecurityGateway#region}
    */
    readonly region: string;
    /**
    * internet_gateway block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#internet_gateway BeyondcorpSecurityGateway#internet_gateway}
    */
    readonly internetGateway?: BeyondcorpSecurityGatewayHubsInternetGateway;
}
export declare function beyondcorpSecurityGatewayHubsToTerraform(struct?: BeyondcorpSecurityGatewayHubs | cdktf.IResolvable): any;
export declare function beyondcorpSecurityGatewayHubsToHclTerraform(struct?: BeyondcorpSecurityGatewayHubs | cdktf.IResolvable): any;
export declare class BeyondcorpSecurityGatewayHubsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): BeyondcorpSecurityGatewayHubs | cdktf.IResolvable | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayHubs | cdktf.IResolvable | undefined);
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _internetGateway;
    get internetGateway(): BeyondcorpSecurityGatewayHubsInternetGatewayOutputReference;
    putInternetGateway(value: BeyondcorpSecurityGatewayHubsInternetGateway): void;
    resetInternetGateway(): void;
    get internetGatewayInput(): BeyondcorpSecurityGatewayHubsInternetGateway | undefined;
}
export declare class BeyondcorpSecurityGatewayHubsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: BeyondcorpSecurityGatewayHubs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): BeyondcorpSecurityGatewayHubsOutputReference;
}
export interface BeyondcorpSecurityGatewayTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#create BeyondcorpSecurityGateway#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#delete BeyondcorpSecurityGateway#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#update BeyondcorpSecurityGateway#update}
    */
    readonly update?: string;
}
export declare function beyondcorpSecurityGatewayTimeoutsToTerraform(struct?: BeyondcorpSecurityGatewayTimeouts | cdktf.IResolvable): any;
export declare function beyondcorpSecurityGatewayTimeoutsToHclTerraform(struct?: BeyondcorpSecurityGatewayTimeouts | cdktf.IResolvable): any;
export declare class BeyondcorpSecurityGatewayTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): BeyondcorpSecurityGatewayTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: BeyondcorpSecurityGatewayTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway google_beyondcorp_security_gateway}
*/
export declare class BeyondcorpSecurityGateway extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_beyondcorp_security_gateway";
    /**
    * Generates CDKTF code for importing a BeyondcorpSecurityGateway resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the BeyondcorpSecurityGateway to import
    * @param importFromId The id of the existing BeyondcorpSecurityGateway that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the BeyondcorpSecurityGateway to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/beyondcorp_security_gateway google_beyondcorp_security_gateway} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options BeyondcorpSecurityGatewayConfig
    */
    constructor(scope: Construct, id: string, config: BeyondcorpSecurityGatewayConfig);
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    get externalIps(): string[];
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _securityGatewayId?;
    get securityGatewayId(): string;
    set securityGatewayId(value: string);
    get securityGatewayIdInput(): string | undefined;
    get state(): string;
    get updateTime(): string;
    private _hubs;
    get hubs(): BeyondcorpSecurityGatewayHubsList;
    putHubs(value: BeyondcorpSecurityGatewayHubs[] | cdktf.IResolvable): void;
    resetHubs(): void;
    get hubsInput(): cdktf.IResolvable | BeyondcorpSecurityGatewayHubs[] | undefined;
    private _timeouts;
    get timeouts(): BeyondcorpSecurityGatewayTimeoutsOutputReference;
    putTimeouts(value: BeyondcorpSecurityGatewayTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | BeyondcorpSecurityGatewayTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
