/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IamOrganizationsPolicyBindingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. User defined annotations. See https://google.aip.dev/148#annotations for more details such as format and size limitations
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#annotations IamOrganizationsPolicyBinding#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Optional. The description of the policy binding. Must be less than or equal to 63 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#display_name IamOrganizationsPolicyBinding#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#id IamOrganizationsPolicyBinding#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location of the Policy Binding
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#location IamOrganizationsPolicyBinding#location}
    */
    readonly location: string;
    /**
    * The parent organization of the Policy Binding.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#organization IamOrganizationsPolicyBinding#organization}
    */
    readonly organization: string;
    /**
    * Required. Immutable. The resource name of the policy to be bound. The binding parent and policy must belong to the same Organization (or Project).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#policy IamOrganizationsPolicyBinding#policy}
    */
    readonly policy: string;
    /**
    * The Policy Binding ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#policy_binding_id IamOrganizationsPolicyBinding#policy_binding_id}
    */
    readonly policyBindingId: string;
    /**
    * Immutable. The kind of the policy to attach in this binding. This
    * field must be one of the following:  - Left empty (will be automatically set
    * to the policy kind) - The input policy kind   Possible values:  POLICY_KIND_UNSPECIFIED PRINCIPAL_ACCESS_BOUNDARY ACCESS
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#policy_kind IamOrganizationsPolicyBinding#policy_kind}
    */
    readonly policyKind?: string;
    /**
    * condition block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#condition IamOrganizationsPolicyBinding#condition}
    */
    readonly condition?: IamOrganizationsPolicyBindingCondition;
    /**
    * target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#target IamOrganizationsPolicyBinding#target}
    */
    readonly target: IamOrganizationsPolicyBindingTarget;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#timeouts IamOrganizationsPolicyBinding#timeouts}
    */
    readonly timeouts?: IamOrganizationsPolicyBindingTimeouts;
}
export interface IamOrganizationsPolicyBindingCondition {
    /**
    * Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#description IamOrganizationsPolicyBinding#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#expression IamOrganizationsPolicyBinding#expression}
    */
    readonly expression?: string;
    /**
    * Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#location IamOrganizationsPolicyBinding#location}
    */
    readonly location?: string;
    /**
    * Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#title IamOrganizationsPolicyBinding#title}
    */
    readonly title?: string;
}
export declare function iamOrganizationsPolicyBindingConditionToTerraform(struct?: IamOrganizationsPolicyBindingConditionOutputReference | IamOrganizationsPolicyBindingCondition): any;
export declare function iamOrganizationsPolicyBindingConditionToHclTerraform(struct?: IamOrganizationsPolicyBindingConditionOutputReference | IamOrganizationsPolicyBindingCondition): any;
export declare class IamOrganizationsPolicyBindingConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IamOrganizationsPolicyBindingCondition | undefined;
    set internalValue(value: IamOrganizationsPolicyBindingCondition | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    resetExpression(): void;
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface IamOrganizationsPolicyBindingTarget {
    /**
    * Required. Immutable. The resource name of the policy to be bound.
    * The binding parent and policy must belong to the same Organization (or Project).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#principal_set IamOrganizationsPolicyBinding#principal_set}
    */
    readonly principalSet?: string;
}
export declare function iamOrganizationsPolicyBindingTargetToTerraform(struct?: IamOrganizationsPolicyBindingTargetOutputReference | IamOrganizationsPolicyBindingTarget): any;
export declare function iamOrganizationsPolicyBindingTargetToHclTerraform(struct?: IamOrganizationsPolicyBindingTargetOutputReference | IamOrganizationsPolicyBindingTarget): any;
export declare class IamOrganizationsPolicyBindingTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IamOrganizationsPolicyBindingTarget | undefined;
    set internalValue(value: IamOrganizationsPolicyBindingTarget | undefined);
    private _principalSet?;
    get principalSet(): string;
    set principalSet(value: string);
    resetPrincipalSet(): void;
    get principalSetInput(): string | undefined;
}
export interface IamOrganizationsPolicyBindingTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#create IamOrganizationsPolicyBinding#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#delete IamOrganizationsPolicyBinding#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#update IamOrganizationsPolicyBinding#update}
    */
    readonly update?: string;
}
export declare function iamOrganizationsPolicyBindingTimeoutsToTerraform(struct?: IamOrganizationsPolicyBindingTimeouts | cdktf.IResolvable): any;
export declare function iamOrganizationsPolicyBindingTimeoutsToHclTerraform(struct?: IamOrganizationsPolicyBindingTimeouts | cdktf.IResolvable): any;
export declare class IamOrganizationsPolicyBindingTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IamOrganizationsPolicyBindingTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: IamOrganizationsPolicyBindingTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding google_iam_organizations_policy_binding}
*/
export declare class IamOrganizationsPolicyBinding extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iam_organizations_policy_binding";
    /**
    * Generates CDKTF code for importing a IamOrganizationsPolicyBinding resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IamOrganizationsPolicyBinding to import
    * @param importFromId The id of the existing IamOrganizationsPolicyBinding that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IamOrganizationsPolicyBinding to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/iam_organizations_policy_binding google_iam_organizations_policy_binding} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IamOrganizationsPolicyBindingConfig
    */
    constructor(scope: Construct, id: string, config: IamOrganizationsPolicyBindingConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _policy?;
    get policy(): string;
    set policy(value: string);
    get policyInput(): string | undefined;
    private _policyBindingId?;
    get policyBindingId(): string;
    set policyBindingId(value: string);
    get policyBindingIdInput(): string | undefined;
    private _policyKind?;
    get policyKind(): string;
    set policyKind(value: string);
    resetPolicyKind(): void;
    get policyKindInput(): string | undefined;
    get policyUid(): string;
    get uid(): string;
    get updateTime(): string;
    private _condition;
    get condition(): IamOrganizationsPolicyBindingConditionOutputReference;
    putCondition(value: IamOrganizationsPolicyBindingCondition): void;
    resetCondition(): void;
    get conditionInput(): IamOrganizationsPolicyBindingCondition | undefined;
    private _target;
    get target(): IamOrganizationsPolicyBindingTargetOutputReference;
    putTarget(value: IamOrganizationsPolicyBindingTarget): void;
    get targetInput(): IamOrganizationsPolicyBindingTarget | undefined;
    private _timeouts;
    get timeouts(): IamOrganizationsPolicyBindingTimeoutsOutputReference;
    putTimeouts(value: IamOrganizationsPolicyBindingTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | IamOrganizationsPolicyBindingTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
