/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RedisClusterUserCreatedConnectionsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#id RedisClusterUserCreatedConnections#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Redis cluster these endpoints should be added to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#name RedisClusterUserCreatedConnections#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#project RedisClusterUserCreatedConnections#project}
    */
    readonly project?: string;
    /**
    * The name of the region of the Redis cluster these endpoints should be added to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#region RedisClusterUserCreatedConnections#region}
    */
    readonly region: string;
    /**
    * cluster_endpoints block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#cluster_endpoints RedisClusterUserCreatedConnections#cluster_endpoints}
    */
    readonly clusterEndpoints?: RedisClusterUserCreatedConnectionsClusterEndpoints[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#timeouts RedisClusterUserCreatedConnections#timeouts}
    */
    readonly timeouts?: RedisClusterUserCreatedConnectionsTimeouts;
}
export interface RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection {
    /**
    * The IP allocated on the consumer network for the PSC forwarding rule.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#address RedisClusterUserCreatedConnections#address}
    */
    readonly address: string;
    /**
    * The URI of the consumer side forwarding rule.
    * Format:
    * projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#forwarding_rule RedisClusterUserCreatedConnections#forwarding_rule}
    */
    readonly forwardingRule: string;
    /**
    * The consumer network where the IP address resides, in the form of
    * projects/{project_id}/global/networks/{network_id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#network RedisClusterUserCreatedConnections#network}
    */
    readonly network: string;
    /**
    * The consumer project_id where the forwarding rule is created from.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#project_id RedisClusterUserCreatedConnections#project_id}
    */
    readonly projectId?: string;
    /**
    * The PSC connection id of the forwarding rule connected to the
    * service attachment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#psc_connection_id RedisClusterUserCreatedConnections#psc_connection_id}
    */
    readonly pscConnectionId: string;
    /**
    * The service attachment which is the target of the PSC connection, in the form of projects/{project-id}/regions/{region}/serviceAttachments/{service-attachment-id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#service_attachment RedisClusterUserCreatedConnections#service_attachment}
    */
    readonly serviceAttachment: string;
}
export declare function redisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionToTerraform(struct?: RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference | RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection): any;
export declare function redisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionToHclTerraform(struct?: RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference | RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection): any;
export declare class RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection | undefined;
    set internalValue(value: RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection | undefined);
    private _address?;
    get address(): string;
    set address(value: string);
    get addressInput(): string | undefined;
    get connectionType(): string;
    private _forwardingRule?;
    get forwardingRule(): string;
    set forwardingRule(value: string);
    get forwardingRuleInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _pscConnectionId?;
    get pscConnectionId(): string;
    set pscConnectionId(value: string);
    get pscConnectionIdInput(): string | undefined;
    get pscConnectionStatus(): string;
    private _serviceAttachment?;
    get serviceAttachment(): string;
    set serviceAttachment(value: string);
    get serviceAttachmentInput(): string | undefined;
}
export interface RedisClusterUserCreatedConnectionsClusterEndpointsConnections {
    /**
    * psc_connection block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#psc_connection RedisClusterUserCreatedConnections#psc_connection}
    */
    readonly pscConnection?: RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection;
}
export declare function redisClusterUserCreatedConnectionsClusterEndpointsConnectionsToTerraform(struct?: RedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable): any;
export declare function redisClusterUserCreatedConnectionsClusterEndpointsConnectionsToHclTerraform(struct?: RedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable): any;
export declare class RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable | undefined;
    set internalValue(value: RedisClusterUserCreatedConnectionsClusterEndpointsConnections | cdktf.IResolvable | undefined);
    private _pscConnection;
    get pscConnection(): RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnectionOutputReference;
    putPscConnection(value: RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection): void;
    resetPscConnection(): void;
    get pscConnectionInput(): RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsPscConnection | undefined;
}
export declare class RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsOutputReference;
}
export interface RedisClusterUserCreatedConnectionsClusterEndpoints {
    /**
    * connections block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#connections RedisClusterUserCreatedConnections#connections}
    */
    readonly connections?: RedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | cdktf.IResolvable;
}
export declare function redisClusterUserCreatedConnectionsClusterEndpointsToTerraform(struct?: RedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable): any;
export declare function redisClusterUserCreatedConnectionsClusterEndpointsToHclTerraform(struct?: RedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable): any;
export declare class RedisClusterUserCreatedConnectionsClusterEndpointsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable | undefined;
    set internalValue(value: RedisClusterUserCreatedConnectionsClusterEndpoints | cdktf.IResolvable | undefined);
    private _connections;
    get connections(): RedisClusterUserCreatedConnectionsClusterEndpointsConnectionsList;
    putConnections(value: RedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | cdktf.IResolvable): void;
    resetConnections(): void;
    get connectionsInput(): cdktf.IResolvable | RedisClusterUserCreatedConnectionsClusterEndpointsConnections[] | undefined;
}
export declare class RedisClusterUserCreatedConnectionsClusterEndpointsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RedisClusterUserCreatedConnectionsClusterEndpoints[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RedisClusterUserCreatedConnectionsClusterEndpointsOutputReference;
}
export interface RedisClusterUserCreatedConnectionsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#create RedisClusterUserCreatedConnections#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#delete RedisClusterUserCreatedConnections#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#update RedisClusterUserCreatedConnections#update}
    */
    readonly update?: string;
}
export declare function redisClusterUserCreatedConnectionsTimeoutsToTerraform(struct?: RedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable): any;
export declare function redisClusterUserCreatedConnectionsTimeoutsToHclTerraform(struct?: RedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable): any;
export declare class RedisClusterUserCreatedConnectionsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: RedisClusterUserCreatedConnectionsTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections google_redis_cluster_user_created_connections}
*/
export declare class RedisClusterUserCreatedConnections extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_redis_cluster_user_created_connections";
    /**
    * Generates CDKTF code for importing a RedisClusterUserCreatedConnections resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RedisClusterUserCreatedConnections to import
    * @param importFromId The id of the existing RedisClusterUserCreatedConnections that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RedisClusterUserCreatedConnections to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/redis_cluster_user_created_connections google_redis_cluster_user_created_connections} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RedisClusterUserCreatedConnectionsConfig
    */
    constructor(scope: Construct, id: string, config: RedisClusterUserCreatedConnectionsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
    private _clusterEndpoints;
    get clusterEndpoints(): RedisClusterUserCreatedConnectionsClusterEndpointsList;
    putClusterEndpoints(value: RedisClusterUserCreatedConnectionsClusterEndpoints[] | cdktf.IResolvable): void;
    resetClusterEndpoints(): void;
    get clusterEndpointsInput(): cdktf.IResolvable | RedisClusterUserCreatedConnectionsClusterEndpoints[] | undefined;
    private _timeouts;
    get timeouts(): RedisClusterUserCreatedConnectionsTimeoutsOutputReference;
    putTimeouts(value: RedisClusterUserCreatedConnectionsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | RedisClusterUserCreatedConnectionsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
