/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SccOrganizationSccBigQueryExportConfig extends cdktf.TerraformMetaArguments {
    /**
    * This must be unique within the organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#big_query_export_id SccOrganizationSccBigQueryExport#big_query_export_id}
    */
    readonly bigQueryExportId: string;
    /**
    * The dataset to write findings' updates to.
    * Its format is "projects/[projectId]/datasets/[bigquery_dataset_id]".
    * BigQuery Dataset unique ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#dataset SccOrganizationSccBigQueryExport#dataset}
    */
    readonly dataset?: string;
    /**
    * The description of the notification config (max of 1024 characters).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#description SccOrganizationSccBigQueryExport#description}
    */
    readonly description?: string;
    /**
    * Expression that defines the filter to apply across create/update
    * events of findings. The
    * expression is a list of zero or more restrictions combined via
    * logical operators AND and OR. Parentheses are supported, and OR
    * has higher precedence than AND.
    *
    * Restrictions have the form <field> <operator> <value> and may have
    * a - character in front of them to indicate negation. The fields
    * map to those defined in the corresponding resource.
    *
    * The supported operators are:
    *
    * * = for all value types.
    * * \>, <, >=, <= for integer values.
    * * :, meaning substring matching, for strings.
    *
    * The supported value types are:
    *
    * * string literals in quotes.
    * * integer literals without quotes.
    * * boolean literals true and false without quotes.
    *
    * See
    * [Filtering notifications](https://cloud.google.com/security-command-center/docs/how-to-api-filter-notifications)
    * for information on how to write a filter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#filter SccOrganizationSccBigQueryExport#filter}
    */
    readonly filter?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#id SccOrganizationSccBigQueryExport#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The organization whose Cloud Security Command Center the Big Query Export
    * Config lives in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#organization SccOrganizationSccBigQueryExport#organization}
    */
    readonly organization: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#timeouts SccOrganizationSccBigQueryExport#timeouts}
    */
    readonly timeouts?: SccOrganizationSccBigQueryExportTimeouts;
}
export interface SccOrganizationSccBigQueryExportTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#create SccOrganizationSccBigQueryExport#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#delete SccOrganizationSccBigQueryExport#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#update SccOrganizationSccBigQueryExport#update}
    */
    readonly update?: string;
}
export declare function sccOrganizationSccBigQueryExportTimeoutsToTerraform(struct?: SccOrganizationSccBigQueryExportTimeouts | cdktf.IResolvable): any;
export declare function sccOrganizationSccBigQueryExportTimeoutsToHclTerraform(struct?: SccOrganizationSccBigQueryExportTimeouts | cdktf.IResolvable): any;
export declare class SccOrganizationSccBigQueryExportTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccOrganizationSccBigQueryExportTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SccOrganizationSccBigQueryExportTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export google_scc_organization_scc_big_query_export}
*/
export declare class SccOrganizationSccBigQueryExport extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_organization_scc_big_query_export";
    /**
    * Generates CDKTF code for importing a SccOrganizationSccBigQueryExport resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SccOrganizationSccBigQueryExport to import
    * @param importFromId The id of the existing SccOrganizationSccBigQueryExport that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SccOrganizationSccBigQueryExport to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/scc_organization_scc_big_query_export google_scc_organization_scc_big_query_export} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SccOrganizationSccBigQueryExportConfig
    */
    constructor(scope: Construct, id: string, config: SccOrganizationSccBigQueryExportConfig);
    private _bigQueryExportId?;
    get bigQueryExportId(): string;
    set bigQueryExportId(value: string);
    get bigQueryExportIdInput(): string | undefined;
    get createTime(): string;
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    resetDataset(): void;
    get datasetInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get mostRecentEditor(): string;
    get name(): string;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    get principal(): string;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): SccOrganizationSccBigQueryExportTimeoutsOutputReference;
    putTimeouts(value: SccOrganizationSccBigQueryExportTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SccOrganizationSccBigQueryExportTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
