/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SiteVerificationWebResourceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#id SiteVerificationWebResource#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The verification method for the Site Verification system to use to verify
    * this site or domain. Possible values: ["ANALYTICS", "DNS_CNAME", "DNS_TXT", "FILE", "META", "TAG_MANAGER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#verification_method SiteVerificationWebResource#verification_method}
    */
    readonly verificationMethod: string;
    /**
    * site block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#site SiteVerificationWebResource#site}
    */
    readonly site: SiteVerificationWebResourceSite;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#timeouts SiteVerificationWebResource#timeouts}
    */
    readonly timeouts?: SiteVerificationWebResourceTimeouts;
}
export interface SiteVerificationWebResourceSite {
    /**
    * The site identifier. If the type is set to SITE, the identifier is a URL. If the type is
    * set to INET_DOMAIN, the identifier is a domain name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#identifier SiteVerificationWebResource#identifier}
    */
    readonly identifier: string;
    /**
    * The type of resource to be verified. Possible values: ["INET_DOMAIN", "SITE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#type SiteVerificationWebResource#type}
    */
    readonly type: string;
}
export declare function siteVerificationWebResourceSiteToTerraform(struct?: SiteVerificationWebResourceSiteOutputReference | SiteVerificationWebResourceSite): any;
export declare function siteVerificationWebResourceSiteToHclTerraform(struct?: SiteVerificationWebResourceSiteOutputReference | SiteVerificationWebResourceSite): any;
export declare class SiteVerificationWebResourceSiteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SiteVerificationWebResourceSite | undefined;
    set internalValue(value: SiteVerificationWebResourceSite | undefined);
    private _identifier?;
    get identifier(): string;
    set identifier(value: string);
    get identifierInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface SiteVerificationWebResourceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#create SiteVerificationWebResource#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#delete SiteVerificationWebResource#delete}
    */
    readonly delete?: string;
}
export declare function siteVerificationWebResourceTimeoutsToTerraform(struct?: SiteVerificationWebResourceTimeouts | cdktf.IResolvable): any;
export declare function siteVerificationWebResourceTimeoutsToHclTerraform(struct?: SiteVerificationWebResourceTimeouts | cdktf.IResolvable): any;
export declare class SiteVerificationWebResourceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SiteVerificationWebResourceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SiteVerificationWebResourceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource google_site_verification_web_resource}
*/
export declare class SiteVerificationWebResource extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_site_verification_web_resource";
    /**
    * Generates CDKTF code for importing a SiteVerificationWebResource resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SiteVerificationWebResource to import
    * @param importFromId The id of the existing SiteVerificationWebResource that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SiteVerificationWebResource to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/site_verification_web_resource google_site_verification_web_resource} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SiteVerificationWebResourceConfig
    */
    constructor(scope: Construct, id: string, config: SiteVerificationWebResourceConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get owners(): string[];
    private _verificationMethod?;
    get verificationMethod(): string;
    set verificationMethod(value: string);
    get verificationMethodInput(): string | undefined;
    get webResourceId(): string;
    private _site;
    get site(): SiteVerificationWebResourceSiteOutputReference;
    putSite(value: SiteVerificationWebResourceSite): void;
    get siteInput(): SiteVerificationWebResourceSite | undefined;
    private _timeouts;
    get timeouts(): SiteVerificationWebResourceTimeoutsOutputReference;
    putTimeouts(value: SiteVerificationWebResourceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SiteVerificationWebResourceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
