/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VmwareengineClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#id VmwareengineCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The ID of the Cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#name VmwareengineCluster#name}
    */
    readonly name: string;
    /**
    * The resource name of the private cloud to create a new cluster in.
    * Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names.
    * For example: projects/my-project/locations/us-west1-a/privateClouds/my-cloud
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#parent VmwareengineCluster#parent}
    */
    readonly parent: string;
    /**
    * autoscaling_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#autoscaling_settings VmwareengineCluster#autoscaling_settings}
    */
    readonly autoscalingSettings?: VmwareengineClusterAutoscalingSettings;
    /**
    * node_type_configs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#node_type_configs VmwareengineCluster#node_type_configs}
    */
    readonly nodeTypeConfigs?: VmwareengineClusterNodeTypeConfigs[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#timeouts VmwareengineCluster#timeouts}
    */
    readonly timeouts?: VmwareengineClusterTimeouts;
}
export interface VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds {
    /**
    * The utilization triggering the scale-in operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#scale_in VmwareengineCluster#scale_in}
    */
    readonly scaleIn: number;
    /**
    * The utilization triggering the scale-out operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#scale_out VmwareengineCluster#scale_out}
    */
    readonly scaleOut: number;
}
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsToTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference | VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds): any;
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsToHclTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference | VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds): any;
export declare class VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds | undefined;
    set internalValue(value: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds | undefined);
    private _scaleIn?;
    get scaleIn(): number;
    set scaleIn(value: number);
    get scaleInInput(): number | undefined;
    private _scaleOut?;
    get scaleOut(): number;
    set scaleOut(value: number);
    get scaleOutInput(): number | undefined;
}
export interface VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds {
    /**
    * The utilization triggering the scale-in operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#scale_in VmwareengineCluster#scale_in}
    */
    readonly scaleIn: number;
    /**
    * The utilization triggering the scale-out operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#scale_out VmwareengineCluster#scale_out}
    */
    readonly scaleOut: number;
}
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsToTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference | VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds): any;
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsToHclTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference | VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds): any;
export declare class VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds | undefined;
    set internalValue(value: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds | undefined);
    private _scaleIn?;
    get scaleIn(): number;
    set scaleIn(value: number);
    get scaleInInput(): number | undefined;
    private _scaleOut?;
    get scaleOut(): number;
    set scaleOut(value: number);
    get scaleOutInput(): number | undefined;
}
export interface VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds {
    /**
    * The utilization triggering the scale-in operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#scale_in VmwareengineCluster#scale_in}
    */
    readonly scaleIn: number;
    /**
    * The utilization triggering the scale-out operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#scale_out VmwareengineCluster#scale_out}
    */
    readonly scaleOut: number;
}
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsToTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference | VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds): any;
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsToHclTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference | VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds): any;
export declare class VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds | undefined;
    set internalValue(value: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds | undefined);
    private _scaleIn?;
    get scaleIn(): number;
    set scaleIn(value: number);
    get scaleInInput(): number | undefined;
    private _scaleOut?;
    get scaleOut(): number;
    set scaleOut(value: number);
    get scaleOutInput(): number | undefined;
}
export interface VmwareengineClusterAutoscalingSettingsAutoscalingPolicies {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#autoscale_policy_id VmwareengineCluster#autoscale_policy_id}
    */
    readonly autoscalePolicyId: string;
    /**
    * The canonical identifier of the node type to add or remove.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#node_type_id VmwareengineCluster#node_type_id}
    */
    readonly nodeTypeId: string;
    /**
    * Number of nodes to add to a cluster during a scale-out operation.
    * Must be divisible by 2 for stretched clusters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#scale_out_size VmwareengineCluster#scale_out_size}
    */
    readonly scaleOutSize: number;
    /**
    * consumed_memory_thresholds block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#consumed_memory_thresholds VmwareengineCluster#consumed_memory_thresholds}
    */
    readonly consumedMemoryThresholds?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds;
    /**
    * cpu_thresholds block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#cpu_thresholds VmwareengineCluster#cpu_thresholds}
    */
    readonly cpuThresholds?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds;
    /**
    * storage_thresholds block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#storage_thresholds VmwareengineCluster#storage_thresholds}
    */
    readonly storageThresholds?: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds;
}
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesToTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable): any;
export declare function vmwareengineClusterAutoscalingSettingsAutoscalingPoliciesToHclTerraform(struct?: VmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable): any;
export declare class VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable | undefined;
    set internalValue(value: VmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable | undefined);
    private _autoscalePolicyId?;
    get autoscalePolicyId(): string;
    set autoscalePolicyId(value: string);
    get autoscalePolicyIdInput(): string | undefined;
    private _nodeTypeId?;
    get nodeTypeId(): string;
    set nodeTypeId(value: string);
    get nodeTypeIdInput(): string | undefined;
    private _scaleOutSize?;
    get scaleOutSize(): number;
    set scaleOutSize(value: number);
    get scaleOutSizeInput(): number | undefined;
    private _consumedMemoryThresholds;
    get consumedMemoryThresholds(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference;
    putConsumedMemoryThresholds(value: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds): void;
    resetConsumedMemoryThresholds(): void;
    get consumedMemoryThresholdsInput(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds | undefined;
    private _cpuThresholds;
    get cpuThresholds(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference;
    putCpuThresholds(value: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds): void;
    resetCpuThresholds(): void;
    get cpuThresholdsInput(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds | undefined;
    private _storageThresholds;
    get storageThresholds(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference;
    putStorageThresholds(value: VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds): void;
    resetStorageThresholds(): void;
    get storageThresholdsInput(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds | undefined;
}
export declare class VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesOutputReference;
}
export interface VmwareengineClusterAutoscalingSettings {
    /**
    * The minimum duration between consecutive autoscale operations.
    * It starts once addition or removal of nodes is fully completed.
    * Minimum cool down period is 30m.
    * Cool down period must be in whole minutes (for example, 30m, 31m, 50m).
    * Mandatory for successful addition of autoscaling settings in cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#cool_down_period VmwareengineCluster#cool_down_period}
    */
    readonly coolDownPeriod?: string;
    /**
    * Maximum number of nodes of any type in a cluster.
    * Mandatory for successful addition of autoscaling settings in cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#max_cluster_node_count VmwareengineCluster#max_cluster_node_count}
    */
    readonly maxClusterNodeCount?: number;
    /**
    * Minimum number of nodes of any type in a cluster.
    * Mandatory for successful addition of autoscaling settings in cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#min_cluster_node_count VmwareengineCluster#min_cluster_node_count}
    */
    readonly minClusterNodeCount?: number;
    /**
    * autoscaling_policies block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#autoscaling_policies VmwareengineCluster#autoscaling_policies}
    */
    readonly autoscalingPolicies: VmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | cdktf.IResolvable;
}
export declare function vmwareengineClusterAutoscalingSettingsToTerraform(struct?: VmwareengineClusterAutoscalingSettingsOutputReference | VmwareengineClusterAutoscalingSettings): any;
export declare function vmwareengineClusterAutoscalingSettingsToHclTerraform(struct?: VmwareengineClusterAutoscalingSettingsOutputReference | VmwareengineClusterAutoscalingSettings): any;
export declare class VmwareengineClusterAutoscalingSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmwareengineClusterAutoscalingSettings | undefined;
    set internalValue(value: VmwareengineClusterAutoscalingSettings | undefined);
    private _coolDownPeriod?;
    get coolDownPeriod(): string;
    set coolDownPeriod(value: string);
    resetCoolDownPeriod(): void;
    get coolDownPeriodInput(): string | undefined;
    private _maxClusterNodeCount?;
    get maxClusterNodeCount(): number;
    set maxClusterNodeCount(value: number);
    resetMaxClusterNodeCount(): void;
    get maxClusterNodeCountInput(): number | undefined;
    private _minClusterNodeCount?;
    get minClusterNodeCount(): number;
    set minClusterNodeCount(value: number);
    resetMinClusterNodeCount(): void;
    get minClusterNodeCountInput(): number | undefined;
    private _autoscalingPolicies;
    get autoscalingPolicies(): VmwareengineClusterAutoscalingSettingsAutoscalingPoliciesList;
    putAutoscalingPolicies(value: VmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | cdktf.IResolvable): void;
    get autoscalingPoliciesInput(): cdktf.IResolvable | VmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | undefined;
}
export interface VmwareengineClusterNodeTypeConfigs {
    /**
    * Customized number of cores available to each node of the type.
    * This number must always be one of 'nodeType.availableCustomCoreCounts'.
    * If zero is provided max value from 'nodeType.availableCustomCoreCounts' will be used.
    * Once the customer is created then corecount cannot be changed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#custom_core_count VmwareengineCluster#custom_core_count}
    */
    readonly customCoreCount?: number;
    /**
    * The number of nodes of this type in the cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#node_count VmwareengineCluster#node_count}
    */
    readonly nodeCount: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#node_type_id VmwareengineCluster#node_type_id}
    */
    readonly nodeTypeId: string;
}
export declare function vmwareengineClusterNodeTypeConfigsToTerraform(struct?: VmwareengineClusterNodeTypeConfigs | cdktf.IResolvable): any;
export declare function vmwareengineClusterNodeTypeConfigsToHclTerraform(struct?: VmwareengineClusterNodeTypeConfigs | cdktf.IResolvable): any;
export declare class VmwareengineClusterNodeTypeConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VmwareengineClusterNodeTypeConfigs | cdktf.IResolvable | undefined;
    set internalValue(value: VmwareengineClusterNodeTypeConfigs | cdktf.IResolvable | undefined);
    private _customCoreCount?;
    get customCoreCount(): number;
    set customCoreCount(value: number);
    resetCustomCoreCount(): void;
    get customCoreCountInput(): number | undefined;
    private _nodeCount?;
    get nodeCount(): number;
    set nodeCount(value: number);
    get nodeCountInput(): number | undefined;
    private _nodeTypeId?;
    get nodeTypeId(): string;
    set nodeTypeId(value: string);
    get nodeTypeIdInput(): string | undefined;
}
export declare class VmwareengineClusterNodeTypeConfigsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VmwareengineClusterNodeTypeConfigs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VmwareengineClusterNodeTypeConfigsOutputReference;
}
export interface VmwareengineClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#create VmwareengineCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#delete VmwareengineCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#update VmwareengineCluster#update}
    */
    readonly update?: string;
}
export declare function vmwareengineClusterTimeoutsToTerraform(struct?: VmwareengineClusterTimeouts | cdktf.IResolvable): any;
export declare function vmwareengineClusterTimeoutsToHclTerraform(struct?: VmwareengineClusterTimeouts | cdktf.IResolvable): any;
export declare class VmwareengineClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VmwareengineClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: VmwareengineClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster google_vmwareengine_cluster}
*/
export declare class VmwareengineCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_vmwareengine_cluster";
    /**
    * Generates CDKTF code for importing a VmwareengineCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VmwareengineCluster to import
    * @param importFromId The id of the existing VmwareengineCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VmwareengineCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.19.0/docs/resources/vmwareengine_cluster google_vmwareengine_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VmwareengineClusterConfig
    */
    constructor(scope: Construct, id: string, config: VmwareengineClusterConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get management(): cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    get state(): string;
    get uid(): string;
    private _autoscalingSettings;
    get autoscalingSettings(): VmwareengineClusterAutoscalingSettingsOutputReference;
    putAutoscalingSettings(value: VmwareengineClusterAutoscalingSettings): void;
    resetAutoscalingSettings(): void;
    get autoscalingSettingsInput(): VmwareengineClusterAutoscalingSettings | undefined;
    private _nodeTypeConfigs;
    get nodeTypeConfigs(): VmwareengineClusterNodeTypeConfigsList;
    putNodeTypeConfigs(value: VmwareengineClusterNodeTypeConfigs[] | cdktf.IResolvable): void;
    resetNodeTypeConfigs(): void;
    get nodeTypeConfigsInput(): cdktf.IResolvable | VmwareengineClusterNodeTypeConfigs[] | undefined;
    private _timeouts;
    get timeouts(): VmwareengineClusterTimeoutsOutputReference;
    putTimeouts(value: VmwareengineClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | VmwareengineClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
